#line 2 "sieve/sieve-lex.c"

#line 4 "sieve/sieve-lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer sieve_create_buffer
#define yy_delete_buffer sieve_delete_buffer
#define yy_flex_debug sieve_flex_debug
#define yy_init_buffer sieve_init_buffer
#define yy_flush_buffer sieve_flush_buffer
#define yy_load_buffer_state sieve_load_buffer_state
#define yy_switch_to_buffer sieve_switch_to_buffer
#define yyin sievein
#define yyleng sieveleng
#define yylex sievelex
#define yylineno sievelineno
#define yyout sieveout
#define yyrestart sieverestart
#define yytext sievetext
#define yywrap sievewrap
#define yyalloc sievealloc
#define yyrealloc sieverealloc
#define yyfree sievefree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 1
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE sieverestart(sievein  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int sieveleng;

extern FILE *sievein, *sieveout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE sievelex.
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-sievelineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < sieveleng; ++yyl )\
                    if ( sievetext[yyl] == '\n' )\
                        --sievelineno;\
            }while(0)
    #define YY_LINENO_REWIND_TO(dst) \
            do {\
                const char *p;\
                for ( p = yy_cp-1; p >= (dst); --p)\
                    if ( *p == '\n' )\
                        --sievelineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up sievetext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up sievetext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via sieverestart()), so that the user can continue scanning by
	 * just pointing sievein at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when sievetext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int sieveleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow sievewrap()'s to do buffer switches
 * instead of setting up a fresh sievein.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void sieverestart (FILE *input_file  );
void sieve_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE sieve_create_buffer (FILE *file,int size  );
void sieve_delete_buffer (YY_BUFFER_STATE b  );
void sieve_flush_buffer (YY_BUFFER_STATE b  );
void sievepush_buffer_state (YY_BUFFER_STATE new_buffer  );
void sievepop_buffer_state (void );

static void sieveensure_buffer_stack (void );
static void sieve_load_buffer_state (void );
static void sieve_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER sieve_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE sieve_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE sieve_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE sieve_scan_bytes (yyconst char *bytes,int len  );

void *sievealloc (yy_size_t  );
void *sieverealloc (void *,yy_size_t  );
void sievefree (void *  );

#define yy_new_buffer sieve_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        sieveensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            sieve_create_buffer(sievein,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        sieveensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            sieve_create_buffer(sievein,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define sievewrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *sievein = NULL, *sieveout = NULL;

typedef int yy_state_type;

extern int sievelineno;

int sievelineno = 1;

extern char *sievetext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr sievetext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yynoreturn yy_fatal_error (yyconst char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up sievetext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	sieveleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 103
#define YY_END_OF_BUFFER 104
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[501] =
    {   0,
        0,    0,    0,    0,    0,    0,  104,  102,   99,   99,
        8,  100,  102,    9,  102,  102,  102,  102,  102,  102,
      102,  102,  102,  102,  102,  102,  102,  102,  102,  102,
      102,    3,    3,    3,    6,    6,    4,    6,  100,    0,
        9,    9,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   10,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        1,    1,    2,    5,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,   40,    0,
       56,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   22,    0,    0,    0,    0,    0,
        0,   92,    0,    0,    0,    0,    0,    0,    0,    0,
      101,    0,   64,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       43,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,   69,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   21,    0,   79,    0,
        0,   12,    0,    0,    0,    0,    0,    0,    0,    0,
       29,    0,   36,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   23,   31,    0,    0,   17,    0,    0,  101,
        0,    0,    0,   78,    0,    0,   48,    0,    0,    0,
       52,    0,    0,   45,    0,   82,    0,    0,    0,    0,
        0,    0,   54,    0,   76,    0,    0,   62,    0,    0,
        0,    0,    0,   70,    0,    0,   67,    0,   83,    0,
        0,   14,   13,    0,    0,    0,   11,    0,    0,   16,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   60,    0,    0,    0,   85,    0,    0,   81,
        0,    0,   93,    0,    0,    0,    0,    0,    0,    0,
        0,   59,    0,    0,   63,   94,   61,    0,    0,    0,
        0,    0,    0,   15,    0,    0,   20,    0,    0,    0,
       38,    0,   26,    0,    0,   77,    0,    0,   25,    0,
        7,    7,    0,   37,    0,    0,    0,    0,    0,   87,
       68,   66,   74,   53,   98,    0,    0,    0,    0,   41,
       44,    0,    0,    0,    0,    0,    0,    0,   34,   18,

        0,    0,   32,    0,    0,   24,   72,    0,    0,    0,
        0,   30,    0,   33,    0,    7,    0,    0,    0,    0,
       71,    0,    0,   58,   46,    0,   42,    0,    0,    0,
       49,   51,    0,    0,   39,   19,   27,    0,   88,   28,
        0,    0,    7,   47,    0,    0,   57,    0,    0,   75,
        0,   73,    0,    0,    0,    0,    0,    0,    0,   50,
        0,   65,    0,    0,    0,    0,    0,    0,    0,   35,
        0,   55,   95,    0,    0,   96,   80,    0,    0,    0,
        0,    0,    0,    0,    0,   84,    0,   86,    0,    0,
       97,   89,   90,    0,    0,    0,    0,    0,   91,    0

    } ;

static yyconst YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    5,    6,    1,    1,    1,    1,    1,
        1,    7,    1,    1,    1,    8,    9,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   11,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
       12,    1,    1,    1,   12,    1,   12,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,   13,    1,    1,    1,    1,   14,   15,   16,   17,

       18,   19,   20,   21,   22,   23,   24,   25,   26,   27,
       28,   29,   30,   31,   32,   33,   34,   35,   36,   37,
       38,   39,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst YY_CHAR yy_meta[40] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1
    } ;

static yyconst flex_uint16_t yy_base[507] =
    {   0,
        0,    0,  534,   37,   38,   39,  536,  538,  538,  538,
      538,    0,  528,   36,   49,   30,  506,  499,   36,   60,
       39,   72,   40,  514,   75,  503,  512,   73,   74,  502,
      514,  538,  538,   95,  538,  538,  538,    0,    0,  520,
       84,  538,   47,   81,   93,   88,  501,  100,   98,  106,
      109,  497,  106,  506,  489,  114,   82,  504,  111,  507,
      492,  502,  493,  479,  499,  484,  481,  486,  480,  479,
      475,  487,  483,  482,  474,  491,  538,  488,  485,   95,
      469,  468,  119,  113,  461,  119,  462,  464,  471,  480,
      538,  492,  538,  538,  487,  144,  476,  467,  128,  473,

      452,  456,  462,  473,  458,  457,  457,  463,  538,  465,
      538,  449,  453,  123,  446,   69,  452,  446,  460,  442,
      452,  455,  441,  443,  434,  449,  452,  452,  429,  448,
      435,  445,  437,  434,  129,  432,  431,  420,  426,  438,
      427,  438,  143,  435,  420,  419,  432,  430,  431,  422,
      417,  420,  420,  429,  420,  419,  422,  411,  404,  403,
      401,  416,  416,  404,  410,  398,  412,  415,  414,  149,
      538,  396,  538,  397,  392,  386,  396,  408,  389,  406,
      405,  398,  391,  401,  398,  393,  395,  379,  391,  396,
      391,  392,  375,  385,  387,  378,  385,  380,  381,  369,

      367,  365,  538,  379,  368,  372,  361,  375,  374,  360,
      356,  371,  363,  369,  367,  366,  538,  366,  538,  350,
      368,  538,  362,  355,  346,  360,  355,  351,  357,  340,
      538,  358,  538,  355,  352,  339,  353,  333,  345,  335,
      347,  339,  538,  538,  336,  351,  538,  330,  327,  352,
      340,  343,  149,  538,  323,  322,  538,  332,  331,  320,
      538,  337,  325,  538,  312,  538,  315,  322,  315,  324,
      330,  315,  538,  328,  538,  313,  318,  538,  311,  320,
      300,  309,  317,  538,  303,  302,  538,  314,  538,  317,
      298,  538,  538,  302,  306,  296,  538,  298,  293,  538,

      297,  309,  291,  304,  292,  305,  280,  299,  283,  297,
      283,  286,  281,  297,  290,  166,  285,  286,  275,  275,
      283,  277,  538,  285,  277,  274,  538,  275,  281,  538,
      277,  268,  277,  277,  274,  276,  267,  264,  263,  262,
      252,  538,  270,  270,  538,  266,  538,  264,  251,  249,
      262,  263,  250,  538,  245,  257,  538,  258,  238,  241,
      538,  257,  538,  253,  253,  538,  244,  249,  538,  171,
      538,  265,  175,  538,  239,  234,  251,  237,  230,  538,
      538,  538,  538,  538,  538,  248,  239,  228,  241,  538,
      538,  150,  244,  243,  234,  223,  221,  231,  538,  538,

      235,  213,  538,  232,  221,  538,  538,  230,  233,  213,
      220,  538,  226,  538,  177,  180,  216,  224,  208,  208,
      538,  208,  207,  538,  538,  212,  538,  211,  210,  209,
      538,  538,  202,  218,  538,  538,  538,  194,  212,  538,
      215,  195,  538,  538,  195,  198,  538,  192,  192,  538,
      184,  538,  205,  189,  187,  197,  181,  197,  202,  538,
      184,  538,  181,  185,  196,  178,  192,  177,  186,  538,
      190,  538,  538,  179,  191,  538,  538,  171,  171,  188,
      183,  169,  167,  165,  164,  538,  179,  538,  163,  180,
      538,  538,  175,  139,  149,  134,   96,   86,  538,  538,

      184,  186,   72,   48,  188,  190
    } ;

static yyconst flex_int16_t yy_def[507] =
    {   0,
      500,    1,  501,  501,  502,  502,  500,  500,  500,  500,
      500,  503,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  504,  503,  505,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  505,  505,  500,  500,  500,  500,

      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  505,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,

      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  505,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,

      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  506,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,

      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  506,  506,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,    0,

      500,  500,  500,  500,  500,  500
    } ;

static yyconst flex_uint16_t yy_nxt[578] =
    {   0,
        8,    9,   10,    9,   11,   12,    8,    8,   13,   14,
       15,    8,    8,   16,   17,   18,   19,   20,   21,    8,
       22,   23,    8,   24,    8,   25,   26,    8,    8,    8,
       27,   28,   29,   30,   31,    8,    8,    8,    8,   33,
       36,   36,   37,   37,   34,   41,   62,   42,   94,   67,
       38,   38,   73,   68,   63,   42,   64,   69,   77,   42,
       74,   42,   43,   97,   44,   45,   78,   46,   47,   48,
       49,   98,   39,   50,   51,   52,   53,   54,   55,   56,
       57,   58,   59,   60,   70,   75,   71,   61,   80,   76,
       84,   87,   81,   41,   85,   42,   72,   91,   92,  127,

      193,  194,   93,   42,   88,   86,  101,   42,   99,   42,
      102,  100,  104,  107,  109,  128,  152,  499,  105,  112,
      103,  108,  115,  113,  110,  153,  116,  125,  498,  111,
      117,  126,  119,  114,  120,  156,  121,  130,  190,  131,
      122,  157,  132,  161,  158,  162,  164,  213,  159,  165,
      170,  160,  171,  174,  175,   96,  176,  250,  191,  214,
      222,  177,  321,  426,  223,  497,  322,  370,  371,  372,
      496,  373,  370,  371,  372,  495,  373,  371,  416,  371,
      416,  427,  443,  416,   32,   32,   35,   35,   95,   95,
      415,  415,  494,  493,  492,  491,  490,  489,  488,  487,

      486,  485,  484,  483,  482,  481,  480,  479,  478,  477,
      476,  475,  474,  473,  472,  471,  470,  469,  468,  467,
      466,  465,  464,  463,  462,  461,  460,  459,  458,  457,
      456,  455,  454,  453,  452,  451,  450,  449,  448,  447,
      446,  445,  444,  442,  441,  440,  439,  438,  437,  436,
      435,  434,  433,  432,  431,  430,  429,  428,  425,  424,
      423,  422,  421,  420,  419,  418,  417,  371,  414,  413,
      412,  411,  410,  409,  408,  407,  406,  405,  404,  403,
      402,  401,  400,  399,  398,  397,  396,  395,  394,  393,
      392,  391,  390,  389,  388,  387,  386,  385,  384,  383,

      382,  381,  380,  379,  378,  377,  376,  375,  374,  369,
      368,  367,  366,  365,  364,  363,  362,  361,  360,  359,
      358,  357,  356,  355,  354,  353,  352,  351,  350,  349,
      348,  347,  346,  345,  344,  343,  342,  341,  340,  339,
      338,  337,  336,  335,  334,  333,  332,  331,  330,  329,
      328,  327,  326,  325,  324,  323,  320,  319,   96,  318,
      317,  316,  315,  314,  313,  312,  311,  310,  309,  308,
      307,  306,  305,  304,  303,  302,  301,  300,  299,  298,
      297,  296,  295,  294,  293,  292,  291,  290,  289,  288,
      287,  286,  285,  284,  283,  282,  281,  280,  279,  278,

      277,  276,  275,  274,  273,  272,  271,  270,  269,  268,
      267,  266,  265,  264,  263,  262,  261,  260,  259,  258,
      257,  256,  255,  254,  253,  252,  251,  249,  248,  247,
      246,  245,  244,  243,  242,  241,  240,  239,  238,  237,
      236,  235,  234,  233,  232,  231,  230,  229,  228,  227,
      226,  225,  224,  221,  220,  219,  218,  217,  216,  215,
      212,  211,  210,  209,  208,  207,  206,  205,  204,  203,
      202,  201,  200,  199,  198,  197,  196,  195,  192,  189,
      188,  187,  186,  185,  184,  183,  182,  181,  180,  179,
      178,  173,  172,   96,   91,  169,  168,  167,  166,  163,

      155,  154,  151,  150,  149,  148,  147,  146,  145,  144,
      143,  142,  141,  140,  139,  138,  137,  136,  135,  134,
      133,  129,  124,  123,  118,  106,   96,   90,   89,   83,
       82,   79,   66,   65,   40,  500,   33,    7,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500
    } ;

static yyconst flex_int16_t yy_chk[578] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    4,
        5,    6,    5,    6,    4,   14,   16,   14,  504,   19,
        5,    6,   21,   19,   16,   14,   16,   19,   23,   14,
       21,   14,   15,   43,   15,   15,   23,   15,   15,   15,
       15,   43,  503,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   20,   22,   20,   15,   25,   22,
       28,   29,   25,   41,   28,   41,   20,   34,   34,   57,

      116,  116,   34,   41,   29,   28,   45,   41,   44,   41,
       45,   44,   46,   48,   49,   57,   80,  498,   46,   50,
       45,   48,   51,   50,   49,   80,   51,   56,  497,   49,
       51,   56,   53,   50,   53,   83,   53,   59,  114,   59,
       53,   83,   59,   84,   83,   84,   86,  135,   83,   86,
       96,   83,   96,   99,   99,  170,   99,  170,  114,  135,
      143,   99,  253,  392,  143,  496,  253,  316,  316,  316,
      495,  316,  370,  370,  370,  494,  370,  373,  373,  415,
      415,  392,  416,  416,  501,  501,  502,  502,  505,  505,
      506,  506,  493,  490,  489,  487,  485,  484,  483,  482,

      481,  480,  479,  478,  475,  474,  471,  469,  468,  467,
      466,  465,  464,  463,  461,  459,  458,  457,  456,  455,
      454,  453,  451,  449,  448,  446,  445,  442,  441,  439,
      438,  434,  433,  430,  429,  428,  426,  423,  422,  420,
      419,  418,  417,  413,  411,  410,  409,  408,  405,  404,
      402,  401,  398,  397,  396,  395,  394,  393,  389,  388,
      387,  386,  379,  378,  377,  376,  375,  372,  368,  367,
      365,  364,  362,  360,  359,  358,  356,  355,  353,  352,
      351,  350,  349,  348,  346,  344,  343,  341,  340,  339,
      338,  337,  336,  335,  334,  333,  332,  331,  329,  328,

      326,  325,  324,  322,  321,  320,  319,  318,  317,  315,
      314,  313,  312,  311,  310,  309,  308,  307,  306,  305,
      304,  303,  302,  301,  299,  298,  296,  295,  294,  291,
      290,  288,  286,  285,  283,  282,  281,  280,  279,  277,
      276,  274,  272,  271,  270,  269,  268,  267,  265,  263,
      262,  260,  259,  258,  256,  255,  252,  251,  250,  249,
      248,  246,  245,  242,  241,  240,  239,  238,  237,  236,
      235,  234,  232,  230,  229,  228,  227,  226,  225,  224,
      223,  221,  220,  218,  216,  215,  214,  213,  212,  211,
      210,  209,  208,  207,  206,  205,  204,  202,  201,  200,

      199,  198,  197,  196,  195,  194,  193,  192,  191,  190,
      189,  188,  187,  186,  185,  184,  183,  182,  181,  180,
      179,  178,  177,  176,  175,  174,  172,  169,  168,  167,
      166,  165,  164,  163,  162,  161,  160,  159,  158,  157,
      156,  155,  154,  153,  152,  151,  150,  149,  148,  147,
      146,  145,  144,  142,  141,  140,  139,  138,  137,  136,
      134,  133,  132,  131,  130,  129,  128,  127,  126,  125,
      124,  123,  122,  121,  120,  119,  118,  117,  115,  113,
      112,  110,  108,  107,  106,  105,  104,  103,  102,  101,
      100,   98,   97,   95,   92,   90,   89,   88,   87,   85,

       82,   81,   79,   78,   76,   75,   74,   73,   72,   71,
       70,   69,   68,   67,   66,   65,   64,   63,   62,   61,
       60,   58,   55,   54,   52,   47,   40,   31,   30,   27,
       26,   24,   18,   17,   13,    7,    3,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[104] =
    {   0,
1, 0, 1, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 
    0, 1, 0, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int sieve_flex_debug;
int sieve_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *sievetext;
#line 1 "sieve/sieve-lex.l"
#line 2 "sieve/sieve-lex.l"
/* sieve.l -- sieve lexer
 * Larry Greenfield
 *
 * Copyright (c) 1994-2016 Carnegie Mellon University.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The name "Carnegie Mellon University" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For permission or any legal
 *    details, please contact
 *      Carnegie Mellon University
 *      Center for Technology Transfer and Enterprise Creation
 *      4615 Forbes Avenue
 *      Suite 302
 *      Pittsburgh, PA  15213
 *      (412) 268-7393, fax: (412) 268-7395
 *      innovation@andrew.cmu.edu
 *
 * 4. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by Computing Services
 *     at Carnegie Mellon University (http://www.cmu.edu/computing/)."
 *
 * CARNEGIE MELLON UNIVERSITY DISCLAIMS ALL WARRANTIES WITH REGARD TO
 * THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS, IN NO EVENT SHALL CARNEGIE MELLON UNIVERSITY BE LIABLE
 * FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
 * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "xmalloc.h"

#include "sieve/tree.h"
#include "sieve/sieve_interface.h"
#include "sieve/sieve.h"

#define YY_NO_INPUT
#define YY_DECL int sievelex(YYSTYPE *yylval,sieve_script_t *parse_script)

static int tonum(char *c);
static char *chkstr(char *);
static char *mlbuf;
static int mlbufsz, mlcur;
extern void sieveerror(sieve_script_t *, char *);


#line 857 "sieve/sieve-lex.c"

#define INITIAL 0
#define MULTILINE 1
#define QSTRING 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int sievelex_destroy (void );

int sieveget_debug (void );

void sieveset_debug (int debug_flag  );

YY_EXTRA_TYPE sieveget_extra (void );

void sieveset_extra (YY_EXTRA_TYPE user_defined  );

FILE *sieveget_in (void );

void sieveset_in  (FILE * _in_str  );

FILE *sieveget_out (void );

void sieveset_out  (FILE * _out_str  );

			int sieveget_leng (void );

char *sieveget_text (void );

int sieveget_lineno (void );

void sieveset_lineno (int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int sievewrap (void );
#else
extern int sievewrap (void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( sievetext, (size_t) sieveleng, 1, sieveout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( sievein )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( sievein ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, max_size, sievein))==0 && ferror(sievein)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(sievein); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int sievelex (void);

#define YY_DECL int sievelex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after sievetext and sieveleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( sieveleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(sievetext[sieveleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! sievein )
			sievein = stdin;

		if ( ! sieveout )
			sieveout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			sieveensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				sieve_create_buffer(sievein,YY_BUF_SIZE );
		}

		sieve_load_buffer_state( );
		}

	{
#line 77 "sieve/sieve-lex.l"

#line 1080 "sieve/sieve-lex.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of sievetext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 501 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 538 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < sieveleng; ++yyl )
				if ( sievetext[yyl] == '\n' )
					
    sievelineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 78 "sieve/sieve-lex.l"
{ BEGIN INITIAL;
                          if (mlbuf) mlbuf[mlcur] = '\0';
                          yylval->sval = chkstr(mlbuf); return STRING; }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 81 "sieve/sieve-lex.l"
{ /* dot stuffing! we want one . */ yyless(1); }
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 82 "sieve/sieve-lex.l"
{ if (mlcur == mlbufsz)
                        mlbuf = xrealloc(mlbuf, 1 + (mlbufsz+=1024));
                    mlbuf[mlcur++] = sievetext[0]; }
	YY_BREAK
case YY_STATE_EOF(MULTILINE):
#line 85 "sieve/sieve-lex.l"
{ BEGIN INITIAL;
                     sieveerror(parse_script, "unexpected end of file in string");
                     if (mlbuf) free(mlbuf);
                     yyterminate(); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 89 "sieve/sieve-lex.l"
{ BEGIN INITIAL;
                     if (mlbuf) mlbuf[mlcur] = '\0';
                     yylval->sval = chkstr(mlbuf); return STRING; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 92 "sieve/sieve-lex.l"
{ if (mlcur == mlbufsz)
                        mlbuf = xrealloc(mlbuf, 1 + (mlbufsz+=1024));
                    mlbuf[mlcur++] = sievetext[1]; }
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 95 "sieve/sieve-lex.l"
{ if (mlcur == mlbufsz)
                        mlbuf = xrealloc(mlbuf, 1 + (mlbufsz+=1024));
                    mlbuf[mlcur++] = sievetext[0]; }
	YY_BREAK
case YY_STATE_EOF(QSTRING):
#line 98 "sieve/sieve-lex.l"
{ sieveerror(parse_script, "unexpected end of file in string");
                    if (mlbuf) free(mlbuf);
                    BEGIN INITIAL;
                    yyterminate(); }
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 102 "sieve/sieve-lex.l"
{ BEGIN MULTILINE;
                          mlcur = 0; mlbufsz = 0; mlbuf = NULL; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 104 "sieve/sieve-lex.l"
{ BEGIN QSTRING;
                    mlcur = 0; mlbufsz = 0; mlbuf = NULL; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 106 "sieve/sieve-lex.l"
{ yylval->nval = tonum(sievetext); return NUMBER; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 107 "sieve/sieve-lex.l"
return IF;
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 108 "sieve/sieve-lex.l"
return ELSIF;
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 109 "sieve/sieve-lex.l"
return ELSE;
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 110 "sieve/sieve-lex.l"
return ANYOF;
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 111 "sieve/sieve-lex.l"
return ALLOF;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 112 "sieve/sieve-lex.l"
return EXISTS;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 113 "sieve/sieve-lex.l"
return SFALSE;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 114 "sieve/sieve-lex.l"
return STRUE;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 115 "sieve/sieve-lex.l"
return ADDRESS;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 116 "sieve/sieve-lex.l"
return ENVELOPE;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 117 "sieve/sieve-lex.l"
return HEADER;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 118 "sieve/sieve-lex.l"
return BODY;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 119 "sieve/sieve-lex.l"
return NOT;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 120 "sieve/sieve-lex.l"
return SIZE;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 121 "sieve/sieve-lex.l"
return yylval->nval = HASFLAG;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 122 "sieve/sieve-lex.l"
return yylval->nval = STRINGT;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 123 "sieve/sieve-lex.l"
return REJCT;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 124 "sieve/sieve-lex.l"
return FILEINTO;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 125 "sieve/sieve-lex.l"
return REDIRECT;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 126 "sieve/sieve-lex.l"
return KEEP;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 127 "sieve/sieve-lex.l"
return REQUIRE;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 128 "sieve/sieve-lex.l"
return STOP;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 129 "sieve/sieve-lex.l"
return DISCARD;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 130 "sieve/sieve-lex.l"
return yylval->nval = SETFLAG;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 131 "sieve/sieve-lex.l"
return yylval->nval = ADDFLAG;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 132 "sieve/sieve-lex.l"
return yylval->nval = REMOVEFLAG;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 133 "sieve/sieve-lex.l"
return MARK;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 134 "sieve/sieve-lex.l"
return UNMARK;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 135 "sieve/sieve-lex.l"
return NOTIFY;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 136 "sieve/sieve-lex.l"
return DENOTIFY;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 137 "sieve/sieve-lex.l"
return ID;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 138 "sieve/sieve-lex.l"
return METHOD;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 139 "sieve/sieve-lex.l"
return OPTIONS;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 140 "sieve/sieve-lex.l"
return LOW;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 141 "sieve/sieve-lex.l"
return NORMAL;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 142 "sieve/sieve-lex.l"
return HIGH;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 143 "sieve/sieve-lex.l"
return MESSAGE;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 144 "sieve/sieve-lex.l"
return VACATION;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 145 "sieve/sieve-lex.l"
return DAYS;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 146 "sieve/sieve-lex.l"
return SECONDS;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 147 "sieve/sieve-lex.l"
return ADDRESSES;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 148 "sieve/sieve-lex.l"
return SUBJECT;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 149 "sieve/sieve-lex.l"
return FROM;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 150 "sieve/sieve-lex.l"
return HANDLE;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 151 "sieve/sieve-lex.l"
return MIME;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 152 "sieve/sieve-lex.l"
return COMPARATOR;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 153 "sieve/sieve-lex.l"
return IS;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 154 "sieve/sieve-lex.l"
return CONTAINS;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 155 "sieve/sieve-lex.l"
return MATCHES;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 156 "sieve/sieve-lex.l"
return REGEX;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 157 "sieve/sieve-lex.l"
return COUNT;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 158 "sieve/sieve-lex.l"
return VALUE;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 159 "sieve/sieve-lex.l"
return OVER;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 160 "sieve/sieve-lex.l"
return UNDER;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 161 "sieve/sieve-lex.l"
return ALL;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 162 "sieve/sieve-lex.l"
return LOCALPART;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 163 "sieve/sieve-lex.l"
return DOMAIN;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 164 "sieve/sieve-lex.l"
return USER;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 165 "sieve/sieve-lex.l"
return DETAIL;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 166 "sieve/sieve-lex.l"
return RAW;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 167 "sieve/sieve-lex.l"
return TEXT;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 168 "sieve/sieve-lex.l"
return CONTENT;
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 169 "sieve/sieve-lex.l"
return INCLUDE;
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 170 "sieve/sieve-lex.l"
return PERSONAL;
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 171 "sieve/sieve-lex.l"
return GLOBAL;
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 172 "sieve/sieve-lex.l"
return OPTIONAL;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 173 "sieve/sieve-lex.l"
return ONCE;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 174 "sieve/sieve-lex.l"
return RETURN;
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 175 "sieve/sieve-lex.l"
return COPY;
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 176 "sieve/sieve-lex.l"
return DATE;
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 177 "sieve/sieve-lex.l"
return CURRENTDATE;
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 178 "sieve/sieve-lex.l"
return INDEX;
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 179 "sieve/sieve-lex.l"
return LAST;
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 180 "sieve/sieve-lex.l"
return ZONE;
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 181 "sieve/sieve-lex.l"
return ORIGINALZONE;
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 182 "sieve/sieve-lex.l"
return FLAGS;
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 183 "sieve/sieve-lex.l"
return MAILBOXEXISTS; /* RFC 5490 */
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 184 "sieve/sieve-lex.l"
return CREATE;
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 185 "sieve/sieve-lex.l"
return METADATA;
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 186 "sieve/sieve-lex.l"
return METADATAEXISTS;
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 187 "sieve/sieve-lex.l"
return SERVERMETADATA;
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 188 "sieve/sieve-lex.l"
return SERVERMETADATAEXISTS;
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 189 "sieve/sieve-lex.l"
return yylval->nval = SET;
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 190 "sieve/sieve-lex.l"
return yylval->nval = LOWER;
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 191 "sieve/sieve-lex.l"
return yylval->nval = UPPER;
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 192 "sieve/sieve-lex.l"
return yylval->nval = LOWERFIRST;
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 193 "sieve/sieve-lex.l"
return yylval->nval = UPPERFIRST;
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 194 "sieve/sieve-lex.l"
return yylval->nval = QUOTEWILDCARD;
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 195 "sieve/sieve-lex.l"
return yylval->nval = LENGTH;
	YY_BREAK
case 99:
/* rule 99 can match eol */
YY_RULE_SETUP
#line 196 "sieve/sieve-lex.l"
;    /* ignore whitespace */
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 197 "sieve/sieve-lex.l"
;          /* ignore hash comments */
	YY_BREAK
case 101:
/* rule 101 can match eol */
YY_RULE_SETUP
#line 198 "sieve/sieve-lex.l"
;  /* ignore bracket comments */
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 199 "sieve/sieve-lex.l"
return sievetext[0];
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 201 "sieve/sieve-lex.l"
ECHO;
	YY_BREAK
#line 1695 "sieve/sieve-lex.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed sievein at a new source and called
			 * sievelex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = sievein;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( sievewrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * sievetext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of sievelex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					sieverealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			sieverestart(sievein  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) sieverealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 501 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 501 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
	yy_is_jam = (yy_current_state == 500);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					sieverestart(sievein );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( sievewrap( ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve sievetext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');
	if ( YY_CURRENT_BUFFER_LVALUE->yy_at_bol )
		
    sievelineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void sieverestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        sieveensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            sieve_create_buffer(sievein,YY_BUF_SIZE );
	}

	sieve_init_buffer(YY_CURRENT_BUFFER,input_file );
	sieve_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void sieve_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		sievepop_buffer_state();
	 *		sievepush_buffer_state(new_buffer);
     */
	sieveensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	sieve_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (sievewrap()) processing, but the only time this flag
	 * is looked at is after sievewrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void sieve_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	sievein = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE sieve_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) sievealloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in sieve_create_buffer()" );

	b->yy_buf_size = (yy_size_t)size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) sievealloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in sieve_create_buffer()" );

	b->yy_is_our_buffer = 1;

	sieve_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with sieve_create_buffer()
 * 
 */
    void sieve_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		sievefree((void *) b->yy_ch_buf  );

	sievefree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a sieverestart() or at EOF.
 */
    static void sieve_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	sieve_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then sieve_init_buffer was _probably_
     * called from sieverestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void sieve_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		sieve_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void sievepush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	sieveensure_buffer_stack();

	/* This block is copied from sieve_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from sieve_switch_to_buffer. */
	sieve_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void sievepop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	sieve_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		sieve_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void sieveensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)sievealloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in sieveensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)sieverealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in sieveensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE sieve_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) sievealloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in sieve_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	sieve_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to sievelex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       sieve_scan_bytes() instead.
 */
YY_BUFFER_STATE sieve_scan_string (yyconst char * yystr )
{
    
	return sieve_scan_bytes(yystr,(int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to sievelex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE sieve_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) sievealloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in sieve_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = sieve_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in sieve_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (yyconst char* msg )
{
			(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up sievetext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		sievetext[sieveleng] = (yy_hold_char); \
		(yy_c_buf_p) = sievetext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		sieveleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int sieveget_lineno  (void)
{
    
    return sievelineno;
}

/** Get the input stream.
 * 
 */
FILE *sieveget_in  (void)
{
        return sievein;
}

/** Get the output stream.
 * 
 */
FILE *sieveget_out  (void)
{
        return sieveout;
}

/** Get the length of the current token.
 * 
 */
int sieveget_leng  (void)
{
        return sieveleng;
}

/** Get the current token.
 * 
 */

char *sieveget_text  (void)
{
        return sievetext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void sieveset_lineno (int  _line_number )
{
    
    sievelineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see sieve_switch_to_buffer
 */
void sieveset_in (FILE *  _in_str )
{
        sievein = _in_str ;
}

void sieveset_out (FILE *  _out_str )
{
        sieveout = _out_str ;
}

int sieveget_debug  (void)
{
        return sieve_flex_debug;
}

void sieveset_debug (int  _bdebug )
{
        sieve_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from sievelex_destroy(), so don't allocate here.
     */

    /* We do not touch sievelineno unless the option is enabled. */
    sievelineno =  1;
    
    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    sievein = stdin;
    sieveout = stdout;
#else
    sievein = NULL;
    sieveout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * sievelex_init()
     */
    return 0;
}

/* sievelex_destroy is for both reentrant and non-reentrant scanners. */
int sievelex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		sieve_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		sievepop_buffer_state();
	}

	/* Destroy the stack itself. */
	sievefree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * sievelex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *sievealloc (yy_size_t  size )
{
			return malloc(size);
}

void *sieverealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void sievefree (void * ptr )
{
			free( (char *) ptr );	/* see sieverealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 201 "sieve/sieve-lex.l"


/*  */
static int tonum(char *c)
{
  int val = atoi(c);
  switch (c[strlen(c)-1]) {
  case 'K': case 'k': val *= (1 << 10); break;
  case 'M': case 'm': val *= (1 << 20); break;
  case 'G': case 'g': val *= (1 << 30); break;
  default: break;
  }
  return val;
}

/* convert NULL strings to "" */
static char *chkstr(char *str)
{
    if (!str) return xstrdup("");
    else return str;
}

